$rcloneDir = Read-Host -Prompt 'Input rclone Directory'
$localDir = Read-Host -Prompt 'Input Local Directory where SFTP should be located'
$type = Read-Host -Prompt 'Type of Server
1) SFTP
2) FTP
Please option select 1 or 2'


if($type -eq 1)
{
    $serverhost = Read-Host -Prompt 'SFTP IP/Hostname'
    $serverport = Read-Host -Prompt 'SFTP Port (Generally Port 22)'
    $username = Read-Host -Prompt 'SFTP Username'
    $password = Read-Host -Prompt 'SFTP Password'
    $selectedType = 'sftp'
    $heading = 'SFTP'
} 
elseif($type -eq 2)
{
    $serverhost = Read-Host -Prompt 'FTP IP/Hostname'
    $serverport = Read-Host -Prompt 'FTP Port (Generally Port 21)'
    $username = Read-Host -Prompt 'FTP Username'
    $password = Read-Host -Prompt 'FTP Password'
    $selectedType = 'ftp'
    $heading = 'FTP'
}

# Launching Rclone and passing password to obscure it.
Write-Output "$(Get-Date): Obsuring $($heading) password"
$obscure  = cmd /c rclone.exe obscure $password

#Creating variable with data for rclone.conf
Write-Output "$(Get-Date): Preparing Rclone File"
$rcloneConfig = '[' + $heading + ']
type = ' + $selectedType + '
host = ' + $serverhost + '
user = ' + $username + '
port = ' + $serverport + '
pass = ' + $obscure + '
use_insecure_cipher = true
md5sum_command = none
sha1sum_command = none'

Write-Output "$(Get-Date): Saving Rclone File"
$rcloneConfigFile = $rcloneDir + '\config.conf'
$rcloneConfig | Out-File -encoding ascii $rcloneConfigFile -Width 200

##Create Bat File For Sync
Write-Output "$(Get-Date): Preparing Batch File"
$batFile = ":loop
ECHO %DATE% %TIME% - Being Running Rclone
" + $rcloneDir + "\rclone.exe --config " + $rcloneConfigFile + " move  " + $heading + ":/ " + $localDir + " --log-level DEBUG
ECHO %DATE% %TIME% - Sleeping for 60 Seconds
timeout /t 60
goto :loop"

Write-Output "$(Get-Date): Saving Batch File"

$SyncBat = $rcloneDir + '\Sync.bat'
$batFile | Out-File -encoding ascii $SyncBat -Width 200


##Create XML Document For ServiceAccount
Write-Output "$(Get-Date): Preparing XML Document"
$serviceXMLFile = '<service>
    <id>vyopta-rclone</id>
    <executable>' + $SyncBat + '</executable>
    <name>Vyopta Rclone</name>
    <description>This service uses rclone to sync data from remote resources locally</description>
    <onfailure action="restart" delay="10 sec"/>
    <resetfailure>1 hour</resetfailure>
    <priority>Normal</priority>
    <stoptimeout>15 sec</stoptimeout>
    <startmode>Automatic</startmode>
    <logpath>' + $rcloneDir + '\logs</logpath>
    <log mode="roll">
        <sizeThreshold>10240</sizeThreshold>
        <keepFiles>8</keepFiles>
    </log>
</service>'

Write-Output "$(Get-Date): Saving XML File"
$serviceXML = $rcloneDir + '\Vyopta-rclone.xml'
$serviceXMLFile | Out-File -encoding ascii $serviceXML -Width 200

$installService = cmd /c Vyopta-rclone.exe install
Write-Output $installService

Write-Output "$(Get-Date): Checking if service has been installed"
$service = Get-Service -Name vyopta-rclone -ErrorAction SilentlyContinue

if ($service.Length -gt 0) 
{
    Write-Output "$(Get-Date): Service Installed Successfully, Starting Service..."
    $startService = cmd /c Vyopta-rclone.exe start
    $arrService = Get-Service -Name vyopta-rclone
    Start-Sleep -seconds 60
    if ($arrService.Status -eq 'Running')
    {
        Write-Host "$(Get-Date): Service is now Running"
    }
    else
    {
        Write-Host "$(Get-Date): Service is NOT Running"
    }
}
else
{
    Write-Output "$(Get-Date): Service Not Installed"
}